@@ -23,20 +23,23 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package Chj::chompspace;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(chompspace);
-#@EXPORT_OK=qw();
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
+
+our @EXPORT = qw(chompspace);
+
+#@EXPORT_OK = qw();
 
 sub chompspace($) {
-    my ($str)=@_;
-    $str=~ s/^\s+//s;
-    $str=~ s/\s+\z//s;
+    my ($str) = @_;
+    $str =~ s/^\s+//s;
+    $str =~ s/\s+\z//s;
     $str
 }
 
-*Chj::chompspace= \&chompspace;
+*Chj::chompspace = \&chompspace;
 
 1;
