@@ -57,56 +57,58 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package Chj::singlequote;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(singlequote);
-@EXPORT_OK=qw(singlequote_sh singlequote_many many with_maxlen
-              possibly_singlequote_sh singlequote_sh_many
-              quote_javascript
-              quote_C _quote_C
-            );
-# importing 'many' is probably not a good idea (depreciated)
-%EXPORT_TAGS=(all=>[@EXPORT, @EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT    = qw(singlequote);
+our @EXPORT_OK = qw(singlequote_sh singlequote_many many with_maxlen
+    possibly_singlequote_sh singlequote_sh_many
+    quote_javascript
+    quote_C _quote_C
+);
+
+# importing 'many' is probably not a good idea (depreciated)
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 our $maybe_maxlen;
 
 sub with_maxlen ($&) {
-    local $maybe_maxlen= $_[0];
-    &{$_[1]}()
+    local $maybe_maxlen = $_[0];
+    &{ $_[1] }()
 }
 
-
 # Perl style:
 
 sub singlequote($ ;$ ) {
-    my ($str,$alternative)=@_;
+    my ($str, $alternative) = @_;
     if (defined $str) {
-        if (defined $maybe_maxlen and length ($str) > $maybe_maxlen) {
-            $str= substr ($str, 0, $maybe_maxlen-3) . "...";
+        if (defined $maybe_maxlen and length($str) > $maybe_maxlen) {
+            $str = substr($str, 0, $maybe_maxlen - 3) . "...";
         }
-        $str=~ s/\'/\\\'/sg;
+        $str =~ s/\'/\\\'/sg;
+
         # avoid newlines (and more?), try to follow the Carp::confess
         # format, if maxlen is given:
-        $str=~ s/([\t\n\r])/sprintf ('\\x{%x}', ord $1)/sge
-          if defined $maybe_maxlen;
+        $str =~ s/([\t\n\r])/sprintf ('\\x{%x}', ord $1)/sge
+            if defined $maybe_maxlen;
         "'$str'"
     } else {
-        defined($alternative)? $alternative:"undef"
+        defined($alternative) ? $alternative : "undef"
     }
 }
-*Chj::singlequote= \&singlequote;
+*Chj::singlequote = \&singlequote;
 
 sub many {
-    my @strs= map {
+    my @strs = map {
         my $str;
-        if (eval { $str= singlequote($_); 1 }) {
+        if (eval { $str = singlequote($_); 1 }) {
             $str
         } else {
-            my $e= "$@";
-            $e=~ s/\n.*//s;
+            my $e = "$@";
+            $e =~ s/\n.*//s;
             "<stringification error: $e>"
         }
     } @_;
@@ -116,27 +118,26 @@ sub many {
         join ", ", @strs
     }
 }
-*singlequote_many= \&many;
-
+*singlequote_many = \&many;
 
 # Shell (Bash) style:
 
 sub singlequote_sh($ ;$ ) {
-    my ($str,$alternative)=@_;
+    my ($str, $alternative) = @_;
     if (defined $str) {
-        $str=~ s/\'/'\\\''/sg;
+        $str =~ s/\'/'\\\''/sg;
         "'$str'"
     } else {
-        defined($alternative)? $alternative:"undef"
+        defined($alternative) ? $alternative : "undef"
     }
 }
-*Chj::singlequote_sh= \&singlequote_sh;
+*Chj::singlequote_sh = \&singlequote_sh;
 
 # don't quote bare words or simply formatted paths that don't need to
 # be quoted
 sub possibly_singlequote_sh ($) {
-    my ($str)=@_;
-    if ($str=~ m{^[\w/.-]+\z}) {
+    my ($str) = @_;
+    if ($str =~ m{^[\w/.-]+\z}) {
         $str
     } else {
         singlequote_sh $str
@@ -147,15 +148,15 @@ sub singlequote_sh_many {
     join " ", map { possibly_singlequote_sh $_ } @_
 }
 
-
 sub quote_javascript ($) {
-    my ($str)=@_;
+    my ($str) = @_;
+
     #require JSON::MaybeXS;
     #JSON->new->allow_nonref(1)->encode($str)
 
     # this doesn't turn special characters into backslash sequences
-    #$str=~ s|\\|\\\\|sg;
-    #$str=~ s|\"|\\\"|sg;
+    #$str =~ s|\\|\\\\|sg;
+    #$str =~ s|\"|\\\"|sg;
     #'"'.$str.'"'
 
     # <mst> if you're obsessed with avoiding dependencies, just use
@@ -163,15 +164,15 @@ sub quote_javascript ($) {
     require JSON::PP;
     JSON::PP->new->allow_nonref(1)->encode($str)
 
-    # <mst> note that JSON::MaybeXS is trivial and fatpacks fine
-    # <mst> intentionally
+        # <mst> note that JSON::MaybeXS is trivial and fatpacks fine
+        # <mst> intentionally
 }
 
 sub _quote_C($) {
-    my ($str)=@_;
-    $str=~ s{(.)}{
-        my $c=$1;
-        my $i= ord $c;
+    my ($str) = @_;
+    $str =~ s{(.)}{
+        my $c = $1;
+        my $i = ord $c;
         # https://en.wikipedia.org/wiki/Ascii
         ($i >= 32 and $i < 127) ?
           ( $c eq '"' ? "\\\"" :
@@ -185,10 +186,9 @@ sub _quote_C($) {
     $str
 }
 
-sub quote_C($){
-    my ($str)=@_;
-    '"'._quote_C($str).'"'
+sub quote_C($) {
+    my ($str) = @_;
+    '"' . _quote_C($str) . '"'
 }
 
-
 1
