@@ -26,7 +26,7 @@ Also see L<FP::Interfaces>.
      package FP::Abstract::ExtendedSequence;
      use base qw(FP::Abstract::Sequence); 
      sub FP_Interface__method_names {
-         my $class= shift;
+         my $class = shift;
          (qw(sum), $class->SUPER::FP_Interface__method_names)
      }
  }
@@ -67,83 +67,87 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Interface;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw();
-@EXPORT_OK=qw(
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
+
+our @EXPORT    = qw();
+our @EXPORT_OK = qw(
     package_is_populated
     require_package
     package_check_possible_interface);
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
-
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 use Carp 'croak';
 
 sub package_is_populated {
-    my ($package)= @_;
+    my ($package) = @_;
     my $pr = do {
         no strict 'refs';
-        *{$package . "::"}
+        *{ $package . "::" }
     };
     %$pr ? 1 : 0
 }
 
 sub require_package ($) {
-    my ($package)=@_;
+    my ($package) = @_;
     if (not package_is_populated $package) {
-        $package=~ s|::|/|g;
-        $package.=".pm";
+        $package =~ s|::|/|g;
+        $package .= ".pm";
         require $package
     }
 }
 
-
 sub package_check_possible_interface ($$) {
-    my ($caller, $possible_interface_package)= @_;
-    if (my $m= UNIVERSAL::can($possible_interface_package,
-                              "FP_Interface__method_names")) {
+    my ($caller, $possible_interface_package) = @_;
+    if (my $m = $possible_interface_package->can("FP_Interface__method_names"))
+    {
         my @missing;
         for my $method (&$m($possible_interface_package)) {
-            unless (UNIVERSAL::can($caller, $method)) {
+            unless ($caller->can($method)) {
                 push @missing, $method
             }
         }
-        warn "FP::Interface warning: '$caller' does not implement '$possible_interface_package' methods: @missing\n"
+        warn
+            "FP::Interface warning: '$caller' does not implement '$possible_interface_package' methods: @missing\n"
             if @missing;
         1
     } else {
+
         # not an interface
         undef
     }
 }
 
 sub implemented_with_caller {
-    @_==2 or die "wrong number of arguments";
-    my ($caller, $interface)= @_;
-    my ($caller_package, $caller_file, $caller_line)= @$caller;
+    @_ == 2 or die "wrong number of arguments";
+    my ($caller, $interface) = @_;
+    my ($caller_package, $caller_file, $caller_line) = @$caller;
     require_package $interface;
     no strict 'refs';
     push @{"${caller_package}::ISA"}, $interface;
     package_check_possible_interface($caller_package, $interface) // do {
-        my $suggestload = package_is_populated($interface) ? ""
+        my $suggestload
+            = package_is_populated($interface)
+            ? ""
             : " (perhaps you forgot to load \"$interface\"?)";
-        die "'$interface' does not have a 'FP_Interface__method_names' method hence is not an interface"
+        die
+            "'$interface' does not have a 'FP_Interface__method_names' method hence is not an interface"
             . $suggestload
-            ." at $caller_file line $caller_line.\n";
+            . " at $caller_file line $caller_line.\n";
     };
 }
 
 # called fully qualified, i.e. FP::Interface::implemented (to avoid
 # namespace pollution in classes)
 sub implemented {
-    @_==1 or
-        croak "FP::Interface::implemented: expecting 1 argument; ".
-              "use FP::Interfaces (note the s) instead";
-    my $caller= [caller];
+    @_ == 1
+        or croak "FP::Interface::implemented: expecting 1 argument; "
+        . "use FP::Interfaces (note the s) instead";
+    my $caller = [caller];
     implemented_with_caller($caller, $_[0])
 }
 
-
 1
