@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2013-2019 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2013-2020 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -26,7 +26,7 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
     };
     like $@, qr/^non-auto-forcing promise accessed via 0\+ operation/;
 
-    my $count= 0;
+    my $count = 0;
     my $b = lazy { $count++; 1 / 2 };
     is is_promise($b), 1;
     is $count, 0;
@@ -39,7 +39,7 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
 
     # The following stores result of `force $b` back into $b
     FORCE $b;
-    is is_promise($b), '';
+    is is_promise($b), undef;
     is $b, 1/2;
     is $count, 1;
 
@@ -48,10 +48,10 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
     # just on the inputs, but also on how many elements were evaluated:
     use FP::Stream qw(stream_map); # uses `lazy` internally
     use FP::List;
-    my $tot=0;
-    my $l= stream_map sub {
-        my ($x)=@_;
-        $tot+=$x;
+    my $tot = 0;
+    my $l = stream_map sub {
+        my ($x) = @_;
+        $tot += $x;
         $x*$x
     }, list (5,7,8);
     is $tot, 0;
@@ -62,10 +62,10 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
 
     # Also note that `local` does mutation (even if in a somewhat
     # controlled way):
-    our $foo= "";
+    our $foo = "";
     sub moo {
-        my ($bar)=@_;
-        local $foo= "Hello";
+        my ($bar) = @_;
+        local $foo = "Hello";
         lazy { "$foo $bar" }
     }
     is moo("you")->force, " you";
@@ -73,7 +73,7 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
     # runtime conditional lazyness:
 
     sub condprom($) {
-        my ($cond)= @_;
+        my ($cond) = @_;
         lazy_if { 1 / 0 } $cond
     }
 
@@ -107,7 +107,7 @@ the saved value.
               # respectively (the commented example forces 3 (possibly)
               # separate values))
 
-    is is_promise($p), ''; # returns true iff $x holds a promise
+    is is_promise($p), undef; # returns true iff $x holds a promise
 
 
 =head1 NOTE
@@ -161,12 +161,12 @@ code that evaluates a promise runs is not the same context in which
 the promise was captured. There are two approaches to make this
 easier:
 
-C<$ENV{DEBUG_FP_LAZY}="1"> or C<local $FP::Lazy::debug=1> -- captures
+C<$ENV{DEBUG_FP_LAZY} = "1"> or C<local $FP::Lazy::debug=1> -- captures
 a backtrace in every promise (slow, of course!). Use the optionally
 exported C<lazy_backtrace> function to get the backtrace (or look at
 it via the repl's :d (Data::Dumper) mode).
 
-C<$ENV{DEBUG_FP_LAZY}="eager"> or C<local $FP::Lazy::eager=1> --
+C<$ENV{DEBUG_FP_LAZY} = "eager"> or C<local $FP::Lazy::eager=1> --
 completely turns of any lazyness (except for lazyLight, currently);
 easy stack traces and flow logic but of course the program behaves
 differently; beware of infinite lists!
@@ -191,89 +191,101 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Lazy;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(lazy lazy_if lazyLight force FORCE is_promise);
-@EXPORT_OK=qw(delay force_noeval lazy_backtrace);
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT      = qw(lazy lazy_if lazyLight force FORCE is_promise);
+our @EXPORT_OK   = qw(delay force_noeval lazy_backtrace);
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 use Carp;
 use FP::Mixin::Utils;
 use FP::Show;
+use Scalar::Util 'blessed';
 
+our $eager = ($ENV{DEBUG_FP_LAZY} and $ENV{DEBUG_FP_LAZY} =~ /^eager$/i);
+our $debug = $ENV{DEBUG_FP_LAZY} ? (not $eager) : '';
 
-our $eager= ($ENV{DEBUG_FP_LAZY} and $ENV{DEBUG_FP_LAZY}=~ /^eager$/i);
-our $debug= $ENV{DEBUG_FP_LAZY} ? (not $eager) : '';
+sub die_not_a_Lazy_Promise {
+    my ($v) = @_;
+    die "not a FP::Lazy::Promise: " . show($v);
+}
 
 # A promise is an array with two fields:
 # index 0: thunk when unevaluated, undef once evaluated
 # index 1: value once evaluated
 # index 2: backtrace if $debug is true
 
-sub lazy_backtrace ($) { # not a method to avoid shadowing any
-                         # 'contained' method
-    my ($v)=@_;
-    UNIVERSAL::isa($v, "FP::Lazy::Promise") # not working for Light ones*!*
-        or die "not a FP::Lazy::Promise: ".show($v);
-    $$v[2]
+sub lazy_backtrace ($) {    # not a method to avoid shadowing any
+                            # 'contained' method
+    my ($v) = @_;
+    blessed($v) // die_not_a_Lazy_Promise($v);
+
+    # Consciously not working for Light ones!
+    if ($v->isa("FP::Lazy::Promise")) {
+        $$v[2]    # really assume such an access works, no fallback to a
+                  # method like in FP::List
+    } else {
+        die_not_a_Lazy_Promise($v);
+    }
 }
 
 sub lazy (&) {
-    $eager ? goto $_[0] :
-        bless [$_[0],
-               undef,
-               $debug && FP::Repl::Stack->get(1)->backtrace
-        ], "FP::Lazy::Promise"
+    $eager
+        ? goto $_[0]
+        : bless [$_[0], undef, $debug && FP::Repl::Stack->get(1)->backtrace],
+        "FP::Lazy::Promise"
 }
 
 sub lazy_if (&$) {
-    (($_[1] and not $eager) ?
-     bless ([$_[0],
-             undef,
-             $debug && FP::Repl::Stack->get(1)->backtrace
-            ], "FP::Lazy::Promise")
-     : do {
-         my ($thunk)=@_;
-         @_=();
-         goto $thunk;
-     })
+    (
+        ($_[1] and not $eager)
+        ? bless([$_[0], undef, $debug && FP::Repl::Stack->get(1)->backtrace],
+            "FP::Lazy::Promise")
+        : do {
+            my ($thunk) = @_;
+            @_ = ();
+            goto $thunk;
+        }
+    )
 }
 
 # not providing for caching (1-time-only evaluation)
 sub lazyLight (&) {
-    $eager ? goto $_[0] :
-        bless $_[0], "FP::Lazy::PromiseLight"
+    $eager ? goto $_[0] : bless $_[0], "FP::Lazy::PromiseLight"
 }
 
 sub is_promise ($) {
-    length ref $_[0] ? UNIVERSAL::isa ($_[0], "FP::Lazy::AnyPromise") : ''
+    blessed($_[0]) // return;
+    $_[0]->isa("FP::Lazy::AnyPromise")
 }
 
-sub delay (&);  *delay = \&lazy;
-sub delayLight (&); *delayLight= \&lazyLight;
-
+sub delay (&);
+*delay = \&lazy;
+sub delayLight (&);
+*delayLight = \&lazyLight;
 
 sub force ($;$) {
-    my ($perhaps_promise,$nocache)=@_;
-  LP: {
-        if (length (my $r= ref $perhaps_promise)) {
-            if (UNIVERSAL::isa ($perhaps_promise, "FP::Lazy::PromiseLight")) {
-                $perhaps_promise= &$perhaps_promise;
+    my ($perhaps_promise, $nocache) = @_;
+LP: {
+        if (defined blessed($perhaps_promise)) {
+            if ($perhaps_promise->isa("FP::Lazy::PromiseLight")) {
+                $perhaps_promise = &$perhaps_promise;
                 redo LP;
-            } elsif (UNIVERSAL::isa ($perhaps_promise, "FP::Lazy::Promise")) {
-                if (my $thunk= $$perhaps_promise[0]) {
-                    my $v= &$thunk();
+            } elsif ($perhaps_promise->isa("FP::Lazy::Promise")) {
+                if (my $thunk = $$perhaps_promise[0]) {
+                    my $v = &$thunk();
                     unless ($nocache) {
-                        $$perhaps_promise[1]= $v;
-                        $$perhaps_promise[0]= undef;
+                        $$perhaps_promise[1] = $v;
+                        $$perhaps_promise[0] = undef;
                     }
-                    $perhaps_promise= $v;
+                    $perhaps_promise = $v;
                     redo LP;
                 } else {
-                    $perhaps_promise= $$perhaps_promise[1];
+                    $perhaps_promise = $$perhaps_promise[1];
                     redo LP;
                 }
             } else {
@@ -287,9 +299,9 @@ sub force ($;$) {
 
 # just remove promise wrapper, don't actually force its evaluation
 sub force_noeval ($) {
-    my ($s)=@_;
-    if (length (my $r= ref $s)) {
-        if (UNIVERSAL::isa ($s, "FP::Lazy::Promise")) {
+    my ($s) = @_;
+    if (defined blessed($s)) {
+        if ($s->isa("FP::Lazy::Promise")) {
             if ($$s[0]) {
                 $s
             } else {
@@ -303,7 +315,6 @@ sub force_noeval ($) {
     }
 }
 
-
 sub FORCE {
     for (@_) {
         $_ = force $_
@@ -311,10 +322,9 @@ sub FORCE {
     wantarray ? @_ : $_[-1]
 }
 
-
 # XX because show did lead to endless loop, (why?) sgh
 sub strshow {
-    my ($v)=@_;
+    my ($v) = @_;
     if (defined $v) {
         require overload;
         overload::StrVal($v)
@@ -323,74 +333,87 @@ sub strshow {
     }
 }
 
-
 # `use overload` arguments, to prevent from accidental use as if it
 # were FP::TransparentLazy
 
-our $allow_access= 0; # true 'turns off' the overload
+our $allow_access = 0;    # true 'turns off' the overload
 
 sub overloads {
-    my ($with_application_overload)= @_;
-    ((map {
-        my $ctx= $_;
-        $ctx=> sub {
-            $allow_access ? $_[0] :
-                Carp::croak "non-auto-forcing promise accessed via $ctx operation"
-        }
-      }
-      ($with_application_overload ? ("&{}") : ()),
-      # (XX can't overload '@{}'?)
-      qw(0+ "" bool qr ${} %{} *{})
-     ),
-     fallback=> 1
+    my ($with_application_overload) = @_;
+    (
+        (
+            map {
+                my $ctx = $_;
+                $ctx => sub {
+                    $allow_access
+                        ? $_[0]
+                        : Carp::croak
+                        "non-auto-forcing promise accessed via $ctx operation"
+                }
+            } ($with_application_overload ? ("&{}") : ()),
+
+            # (XX can't overload '@{}'?)
+            qw(0+ "" bool qr ${} %{} *{})
+        ),
+        fallback => 1
     )
 }
 
 package FP::Lazy::AnyPromise {
 
-    *force= *FP::Lazy::force;
+    *force = *FP::Lazy::force;
 
     sub FORCE {
-        $_[0] = force ($_[0]);
+        $_[0] = force($_[0]);
     }
 
     sub DESTROY {
+
         # nothing, catch this to prevent it from entering AUTOLOAD
     }
 
-    our $AUTOLOAD; # needs to be declared even though magical
+    our $AUTOLOAD;    # needs to be declared even though magical
+
     sub AUTOLOAD {
-        my $methodname= $AUTOLOAD;
-        my $v= force ($_[0]);
+        my $methodname = $AUTOLOAD;
+        my $v          = force($_[0]);
         $methodname =~ s/.*:://;
+
         # To be able to select special implementations for lazy
         # inputs, select a method with `stream_` prefix if present.
-        # (No need to check whether $v is a reference, as the same
-        # code is valid for class names.)
-        my $method=
-          ($methodname=~ /^stream_/ ? UNIVERSAL::can($v, $methodname)
-           : UNIVERSAL::can($v, "stream_$methodname")
-           // UNIVERSAL::can($v, $methodname)
-           // UNIVERSAL::can("FP::Mixin::Utils", $methodname));
+
+        # $v can be either a class name or object; it's guaranteed to
+        # be either of those, thus we can use ->can
+
+        my $method
+            = ($methodname =~ /^stream_/
+            ? $v->can($methodname)
+            : $v->can("stream_$methodname") // $v->can($methodname)
+                // "FP::Mixin::Utils"->can($methodname));
         if ($method) {
+
             # can't change @_ or it would break 'env clearing' ability
             # of the method. Thus assign to $_[0], which will effect
             # our env, too, but so what? XX still somewhat bad.
-            $_[0]= $v; goto &$method;
+            $_[0] = $v;
+            goto &$method;
         } else {
+
             # XX imitate perl's ~exact error message?
             Carp::croak "no method '$methodname' found for object: "
-                .FP::Lazy::strshow($v);
+                . FP::Lazy::strshow($v);
         }
     }
 
+    # XXX TODO: provide a `can` method, right?
+
     # should really have a maybe_ prefix, but since it's for debugging
     # purposes only (and in that case also likely always returns a
     # value) and we like short names for that, leave it at this, ok?
     # XXX avoid spamming with such a short name; use FP_Lazy_bt [or
     # de-priorize it like the FP::Mixin::Utils stuff?]
     sub bt {
-        my $s=shift;
+        my $s = shift;
         $$s[2]
     }
 
@@ -398,15 +421,16 @@ package FP::Lazy::AnyPromise {
 
 use FP::Show qw(subprefix_to_show_coderef);
 
-my $lazy_thunk_show= subprefix_to_show_coderef("lazy ");
+my $lazy_thunk_show = subprefix_to_show_coderef("lazy ");
 
 package FP::Lazy::Promise {
-    our @ISA= 'FP::Lazy::AnyPromise';
+    our @ISA = 'FP::Lazy::AnyPromise';
 
     use overload FP::Lazy::overloads(1);
 
     sub FP_Show_show {
-        my ($s,$show)=@_;
+        my ($s, $show) = @_;
+
         # do not force unforced promises
         if ($$s[0]) {
             &$lazy_thunk_show($$s[0])
@@ -416,19 +440,19 @@ package FP::Lazy::Promise {
     }
 }
 
-my $lazyLight_thunk_show= subprefix_to_show_coderef("lazyLight ");
+my $lazyLight_thunk_show = subprefix_to_show_coderef("lazyLight ");
 
 package FP::Lazy::PromiseLight {
-    our @ISA= qw(FP::Lazy::AnyPromise);
+    our @ISA = qw(FP::Lazy::AnyPromise);
 
     use overload FP::Lazy::overloads(0);
 
     sub FP_Show_show {
-        my ($s,$show)=@_;
+        my ($s, $show) = @_;
+
         # do not force unforced promises
         &$lazyLight_thunk_show($s)
     }
 }
 
-
 1
