@@ -16,7 +16,7 @@ FP::OrderedCollection
     use FP::Equal 'is_equal'; use FP::Stream;
     use FP::OrderedCollection;
 
-    my $c= FP::OrderedCollection->new_from_values(qw(a b c f));
+    my $c = FP::OrderedCollection->new_from_values(qw(a b c f));
     ok $c->contains("a");
     ok not $c->contains("q");
     is $c->maybe_position("1"), undef;
@@ -44,84 +44,82 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::OrderedCollection;
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use FP::Predicates;
-use FP::Stream qw(subarray_to_stream subarray_to_stream_reverse  stream_to_array);
+use FP::Stream
+    qw(subarray_to_stream subarray_to_stream_reverse  stream_to_array);
 use FP::Lazy;
 use FP::List;
 
-use FP::Struct
-  [[\&is_array, "array"],
-   [\&is_hash, "hash"]],
+use FP::Struct [[\&is_array, "array"], [\&is_hash, "hash"]],
     'FP::Abstract::Pure';
 
-
 # Unsafe: assumes that the given array is never mutated after
 # constructing the OrderedCollection
 sub unsafe_new_from_array {
-    my $cl=shift;
-    @_==1 or die "wrong number of arguments";
-    my ($a)=@_;
+    my $cl = shift;
+    @_ == 1 or die "wrong number of arguments";
+    my ($a) = @_;
     my %h;
-    for my $i (0..$#$a) {
-        $h{$$a[$i]}= $i;
+    for my $i (0 .. $#$a) {
+        $h{ $$a[$i] } = $i;
     }
-    $cl->new ($a,\%h)
+    $cl->new($a, \%h)
 }
 
 sub new_from_array {
-    my $cl=shift;
-    @_==1 or die "wrong number of arguments";
-    my ($a)=@_;
-    $cl->unsafe_new_from_array ([@$a])
+    my $cl = shift;
+    @_ == 1 or die "wrong number of arguments";
+    my ($a) = @_;
+    $cl->unsafe_new_from_array([@$a])
 }
 
 sub new_from_values {
-    my $cl=shift;
+    my $cl = shift;
     $cl->unsafe_new_from_array([@_])
 }
 
 sub contains {
-    my $s=shift;
-    @_==1 or die "wrong number of arguments";
-    exists $$s{hash}{$_[0]}
+    my $s = shift;
+    @_ == 1 or die "wrong number of arguments";
+    exists $$s{hash}{ $_[0] }
 }
 
 sub maybe_position {
-    my $s=shift;
-    @_==1 or die "wrong number of arguments";
-    $$s{hash}{$_[0]}
+    my $s = shift;
+    @_ == 1 or die "wrong number of arguments";
+    $$s{hash}{ $_[0] }
 }
 
 sub perhaps_following {
-    my $s=shift;
-    my $i= $s->maybe_position(@_) // return;
-    subarray_to_stream($$s{array}, $i+1)
+    my $s = shift;
+    my $i = $s->maybe_position(@_) // return;
+    subarray_to_stream($$s{array}, $i + 1)
 }
 
 sub perhaps_previous {
-    my $s=shift;
-    my $i= $s->maybe_position(@_) // return;
-    subarray_to_stream_reverse($$s{array}, $i-1)
+    my $s = shift;
+    my $i = $s->maybe_position(@_) // return;
+    subarray_to_stream_reverse($$s{array}, $i - 1)
 }
 
 sub maybe_next {
-    my $s=shift;
-    my ($l)= $s->perhaps_following (@_) or return undef;
-    $l= force ($l);
-    is_null $l ? undef : car $l
+    my $s = shift;
+    my ($l) = $s->perhaps_following(@_) or return undef;
+    $l = force($l);
+    is_null($l) ? undef : car $l
 }
 
 sub maybe_prev {
-    my $s=shift;
-    my ($l)= $s->perhaps_previous (@_) or return undef;
-    $l= force ($l);
-    is_null $l ? undef : car $l
+    my $s = shift;
+    my ($l) = $s->perhaps_previous(@_) or return undef;
+    $l = force($l);
+    is_null($l) ? undef : car $l
 }
 
-
 _END_
