@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2019 Christian Jaeger, copying@christianjaeger.ch
+# Copyright (c) 2015-2020 Christian Jaeger, copying@christianjaeger.ch
 #
 # This is free software, offered under either the same terms as perl 5
 # or the terms of the Artistic License version 2 or the terms of the
@@ -16,7 +16,7 @@ FP::PureArray
     use FP::PureArray;
     use FP::Div 'inc';
 
-    my $a= purearray(1,4,5)->map(*inc);
+    my $a = purearray(1,4,5)->map(*inc);
     is $a->sum, 13;
 
     # can't mutate it:
@@ -27,7 +27,7 @@ FP::PureArray
 
     is $a->sum, 13;
 
-    my $b= $a->unsafe_mutable; # efficient but dangerous!
+    my $b = $a->unsafe_mutable; # efficient but dangerous!
     $$b[0]++;
     is $a->sum, 14; # said it was dangerous!
     is ref($a), 'FP::_::MutableArray';
@@ -84,46 +84,48 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::PureArray;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(is_purearray purearray);
-@EXPORT_OK=qw(array_clone_to_purearray array_to_purearray);
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT      = qw(is_purearray purearray);
+our @EXPORT_OK   = qw(array_clone_to_purearray array_to_purearray);
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 use FP::Interfaces;
 use Carp;
+use Scalar::Util qw(blessed);
 
-
-our $immutable= 1; # whether new instances are to be immutable
-
+our $immutable = 1;    # whether new instances are to be immutable
 
 sub is_purearray ($) {
-    length ref ($_[0]) and UNIVERSAL::isa($_[0], "FP::_::PureArray")
+    my ($v) = @_;
+    my $r = blessed($v) // return;
+    $v->isa("FP::_::PureArray")
 }
 
 sub purearray {
-    FP::_::PureArray->new_from_array ([@_])
+    FP::_::PureArray->new_from_array([@_])
 }
 
 sub array_clone_to_purearray ($) {
-    FP::_::PureArray->new_from_array ([@{$_[0]}])
+    FP::_::PureArray->new_from_array([@{ $_[0] }])
 }
 
 sub array_to_purearray ($) {
-    FP::_::PureArray->new_from_array ($_[0])
+    FP::_::PureArray->new_from_array($_[0])
 }
 
-
 package FP::PureArray::autobox {
     our $AUTOLOAD;
+
     sub AUTOLOAD {
-        my $methodname= $AUTOLOAD;
+        my $methodname = $AUTOLOAD;
         $methodname =~ s/.*:://;
-        my $v= FP::_::PureArray->new_from_array($_[0]);
-        if (my $m= UNIVERSAL::can($v, $methodname)) {
+        my $v = FP::_::PureArray->new_from_array($_[0]);
+        if (my $m = $v->can($methodname)) {
             goto $m
         } else {
             die "no method '$methodname' found for object: $v";
@@ -138,62 +140,61 @@ package FP::_::PureArray {
     use Chj::NamespaceCleanAbove;
 
     sub new_from_array {
-        @_==2 or die "wrong number of arguments";
-        my ($class, $a)=@_;
+        @_ == 2 or die "wrong number of arguments";
+        my ($class, $a) = @_;
         bless $a, $class;
         if ($FP::PureArray::immutable) {
-            Internals::SvREADONLY $_, 1
-                for @$a;
+            Internals::SvREADONLY $_, 1 for @$a;
             Internals::SvREADONLY @$a, 1;
         }
         $a
     }
 
     sub purearray {
-        @_==1 or die "wrong number of arguments";
-        my $s=shift;
+        @_ == 1 or die "wrong number of arguments";
+        my $s = shift;
         $s
     }
 
     sub mutablearray {
-        @_==1 or die "wrong number of arguments";
-        my $s=shift;
+        @_ == 1 or die "wrong number of arguments";
+        my $s = shift;
         FP::_::MutableArray->new_from_array([@$s])
     }
 
     # emptyness constructor that works for subclassing (using singletons
     # for performance (perhaps))
     my %null;
+
     sub null {
-        my $proto=shift;
-        my $class= ref($proto) || $proto;
-        $null{$class} ||= $class->new_from_array([]) 
+        my $proto = shift;
+        my $class = ref($proto) || $proto;
+        $null{$class} ||= $class->new_from_array([])
     }
 
     sub constructor_name {
         "purearray"
     }
 
+    our $pure_warned = 0;
 
-    our $pure_warned= 0;
     sub pure {
-        @_==1 or die "wrong number of arguments";
-        my $a=shift;
+        @_ == 1 or die "wrong number of arguments";
+        my $a = shift;
         carp "is already pure" unless $pure_warned++;
         $a
     }
 
     sub unsafe_mutable {
-        @_==1 or die "wrong number of arguments";
-        my $a=shift;
-        Internals::SvREADONLY $_, 0
-            for @$a;
+        @_ == 1 or die "wrong number of arguments";
+        my $a = shift;
+        Internals::SvREADONLY $_, 0 for @$a;
         Internals::SvREADONLY @$a, 0;
-        require FP::MutableArray; # cost?
-        bless $a, "FP::_::MutableArray" 
+        require FP::MutableArray;    # cost?
+        bless $a, "FP::_::MutableArray"
     }
 
-    _END_; # Chj::NamespaceCleanAbove
+    _END_;                           # Chj::NamespaceCleanAbove
 
     FP::Interfaces::implemented qw(
         FP::Abstract::Pure
