@@ -13,7 +13,7 @@ FP::Repl::Dependencies - hack to load Repl dependencies
 
 =head1 SYNOPSIS
 
-    use Chj::TEST use=> 'FP::Repl::Dependencies';
+    use Chj::TEST use => 'FP::Repl::Dependencies';
 
 =head1 DESCRIPTION
 
@@ -33,20 +33,16 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Repl::Dependencies;
-#@ISA="Exporter"; require Exporter;
-#@EXPORT=qw();
-#@EXPORT_OK=qw();
-#%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
-
-use strict; use warnings; use warnings FATAL => 'uninitialized';
 
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 use Term::ReadLine;
 
 $Term::ReadLine::Gnu::VERSION
-  or die "dependency Term::ReadLine::Gnu not present";
+    or die "dependency Term::ReadLine::Gnu not present";
 
 # now also depend on PadWalker etc.
 require FP::Repl::Repl;
