@@ -27,10 +27,10 @@ FP::Repl::WithRepl
                        # handlers (takes an optional package argument, by
                        # default the caller's package is used)
 
-    my ($v,$e,$is_error)= WithRepl_eval_e("code",$maybe_package);
+    my ($v,$e,$is_error) = WithRepl_eval_e("code",$maybe_package);
                        # unlike WithRepl_eval and eval, this safely
-                       # returns the result of the given code, or $e==$@
-                       # and $is_error==1 in case of an exception/error.
+                       # returns the result of the given code, or $e == $@
+                       # and $is_error == 1 in case of an exception/error.
 
     pop_withrepl; # restore the handler that was pushed last.
 
@@ -55,57 +55,56 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Repl::WithRepl;
-
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(withrepl push_withrepl pop_withrepl);
-@EXPORT_OK=qw(WithRepl_eval WithRepl_eval_e);
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
-
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
 
 #-- moved up here before any lexicals to avoid their exposure--
 # Wrapping `eval` calls with a special frame
 # (`FP::Repl::WithRepl::WithRepl_eval`) that the handler can test for:
 
 sub WithRepl_eval (&;$) {
-    # my ($arg, $maybe_package)=@_;
+
+    # my ($arg, $maybe_package) = @_;
     if (ref $_[0]) {
-        @_==1 or die "wrong number of arguments";
-        my ($arg)=@_;
+        @_ == 1 or die "wrong number of arguments";
+        my ($arg) = @_;
         eval { &$arg() }
     } else {
         eval do {
-            @_==1 or @_==2 or die "wrong number of arguments";
-            my ($arg, $maybe_package)=@_;
-            my $package= $maybe_package // caller;
+            @_ == 1 or @_ == 2 or die "wrong number of arguments";
+            my ($arg, $maybe_package) = @_;
+            my $package = $maybe_package // caller;
             "package $package; $arg"
         }
     }
 }
 
 sub WithRepl_eval_e ($;$$) {
-    # my ($arg, $maybe_package, $wantarray)=@_;
+
+    # my ($arg, $maybe_package, $wantarray) = @_;
     if (ref $_[0]) {
         die "WithRepl_eval_e only supports string eval";
     } else {
-        my $success= eval do {
-            (@_>=1 and @_<=3) or die "wrong number of arguments";
-            my ($arg, $maybe_package, $wantarray)=@_;
-            my $package= $maybe_package // caller;
-            my $scalar= $wantarray ? "" : "scalar";
+        my $success = eval do {
+            (@_ >= 1 and @_ <= 3) or die "wrong number of arguments";
+            my ($arg, $maybe_package, $wantarray) = @_;
+            my $package = $maybe_package // caller;
+            my $scalar  = $wantarray ? "" : "scalar";
             "[ $scalar do { package $package; $arg } ]"
         };
-        my ($arg, $maybe_package, $wantarray)=@_; # now can have the lexicals
-        if ($success) {
-            ($wantarray ? $success : $$success[0], $@, '')
-        } else {
-            (undef, $@, 1)
-        }
+        my ($arg, $maybe_package, $wantarray) = @_;  # now can have the lexicals
+        if ($success) { ($wantarray ? $success : $$success[0], $@, '') }
+        else          { (undef, $@, 1) }
     }
 }
 
+use Exporter "import";
+our @EXPORT      = qw(withrepl push_withrepl pop_withrepl);
+our @EXPORT_OK   = qw(WithRepl_eval WithRepl_eval_e);
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
+
 use FP::Repl;
 use FP::Repl::Stack;
 use Chj::TEST;
@@ -113,21 +112,25 @@ use FP::Show;
 
 # test that 'no' variables are seen (yeah, could do better)
 TEST { &WithRepl_eval('"Hello $arg"') } ();
-TEST { my ($res,$e,$is_err)= WithRepl_eval_e('"Hello $arg"'); $is_err } 1;
-TEST { my ($res,$e,$is_err)= WithRepl_eval_e('[ $res ]'); $is_err } 1;
+TEST { my ($res, $e, $is_err) = WithRepl_eval_e('"Hello $arg"'); $is_err } 1;
+TEST { my ($res, $e, $is_err) = WithRepl_eval_e('[ $res ]'); $is_err } 1;
 
-TEST { my ($res,$e,$is_err)= WithRepl_eval_e q{
-       my @a= (qw(a b c));
+TEST {
+    my ($res, $e, $is_err) = WithRepl_eval_e q{
+       my @a = (qw(a b c));
        @a
        }, "foo";
-       $res } 3;
-TEST { my ($res,$e,$is_err)= WithRepl_eval_e q{
-       my @a= (qw(a b c));
+    $res
+}
+3;
+TEST {
+    my ($res, $e, $is_err) = WithRepl_eval_e q{
+       my @a = (qw(a b c));
        @a
        }, "foo", 1;
-       $res } [qw(a b c)];
-
-
+    $res
+}
+[qw(a b c)];
 
 # PROBLEM: even exceptions within contexts that catch exceptions
 # (i.e. `eval { }`) are invoking a repl, unless we use a workaround.
@@ -137,14 +140,14 @@ TEST { my ($res,$e,$is_err)= WithRepl_eval_e q{
 # solution in XS.
 
 sub current_user_frame ($) {
-    my ($skip)=@_;
+    my ($skip) = @_;
     if ($skip) { $skip >= 0 or die "expecting maybe(natural0), got '$skip'"; }
     my @v;
-    my $i= 0;
-    while ((@v)= caller ($i++)) {
+    my $i = 0;
+    while ((@v) = caller($i++)) {
         if ($v[0] ne "FP::Repl::WithRepl") {
             if ($skip) {
-                unless ((@v) = caller ($i + $skip)) {
+                unless ((@v) = caller($i + $skip)) {
                     die "skip value goes beyond the end of the stack";
                 }
             }
@@ -154,7 +157,6 @@ sub current_user_frame ($) {
     die "???"
 }
 
-
 # have_eval_since_frame: is ignoring eval from repl. Uh, so hacky. But
 # otherwise how to enable WithRepl from within a repl? With a special
 # repl command? But even when previously the handler was enabled, a
@@ -166,121 +168,120 @@ sub current_user_frame ($) {
 our $debug = 0;
 
 sub have_eval_since_frame ($) {
-    my ($startframe)= @_;
+    my ($startframe) = @_;
 
     my @v;
-    my $i=1;
+    my $i = 1;
 
-  SKIP: {
-        while ((@v)= caller $i++) {
+SKIP: {
+        while ((@v) = caller $i++) {
             last SKIP if ($v[0] ne "FP::Repl::WithRepl");
         }
         die "???"
     }
 
     do {
-        my $f= FP::Repl::StackFrame->new(undef, @v);
-        if ($f->equal ($startframe)) {
-            warn "reached startframe, thus return false"
-              if $debug;
+        my $f = FP::Repl::StackFrame->new(undef, @v);
+        if ($f->equal($startframe)) {
+            warn "reached startframe, thus return false" if $debug;
             return ''
         } elsif ($f->subroutine eq "(eval)") {
-            if ((@v)= caller $i++) {
-                my $f= FP::Repl::StackFrame->new(undef, @v);
-                my $sub= $f->subroutine;
+            if ((@v) = caller $i++) {
+                my $f   = FP::Repl::StackFrame->new(undef, @v);
+                my $sub = $f->subroutine;
                 if ($sub =~ /::WithRepl_eval(?:_e)?\z/) {
                     warn "(ignore eval since it's from a WithRepl_eval)"
-                      if $debug;
+                        if $debug;
                 } elsif ($sub =~ /::BEGIN\z/) {
+
                     # (why does BEGIN use eval?)
-                    warn "(ignore eval since it's from a BEGIN)"
-                      if $debug;
+                    warn "(ignore eval since it's from a BEGIN)" if $debug;
                 } else {
-                    warn "GOT eval (standalone)"
-                      if $debug;
+                    warn "GOT eval (standalone)" if $debug;
                     return 1
                 }
             } else {
-                warn "GOT eval right at end of stack"
-                  if $debug;
+                warn "GOT eval right at end of stack" if $debug;
                 return 1
             }
         }
-    }
-      while ((@v)= caller $i++);
+    } while ((@v) = caller $i++);
 
-    warn "couldn't find orig frame!"
-      if $debug;
-      # not even tail-calling should be able to do that, unless, not
-      # local'ized, hm XXX non-popped handler.
+    warn "couldn't find orig frame!" if $debug;
+
+    # not even tail-calling should be able to do that, unless, not
+    # local'ized, hm XXX non-popped handler.
     0
 }
 
-
-
 sub handler_for ($$) {
-    my ($startframe, $orig_handler)=@_;
+    my ($startframe, $orig_handler) = @_;
     bless sub {
-        my ($e)=@_;
+        my ($e) = @_;
+
         # to show local errors with backtrace:
         # require Chj::Backtrace; import Chj::Backtrace;
         if (have_eval_since_frame $startframe) {
-            #$SIG{__DIE__}= $orig_handler;
+
+            #$SIG{__DIE__} = $orig_handler;
             # ^ helps against the loop but makes the push_withrepl
             #   one-shot, of course
             #goto &{$orig_handler // sub { die $_[0] }}  nah, try:
             if (defined $orig_handler) {
+
                 #goto $orig_handler
                 # ^ just doesn't work, seems to undo the looping
                 #   protection. so..:  -- XX test goto &$orig_handler
-                &$orig_handler ($e)
+                &$orig_handler($e)
             } else {
+
                 #warn "no orig_handler, returning";
                 return
             }
         } else {
-            my $err= $FP::Repl::Repl::maybe_output // *STDERR{IO};
-            print $err "Exception: ".show($e)."\n";
+            my $err = $FP::Repl::Repl::maybe_output // *STDERR{IO};
+            print $err "Exception: " . show($e) . "\n";
+
             # then what to do upon exiting it? return the value of the
             # repl?  XX repl needs new feature, a "quit this context
             # with this value". Although not helping anyway since Perl
             # can't be made to avoid leaving the exception context.
-            push_withrepl(0); # XX correct? Argument?
-            repl(skip=> 1)
+            push_withrepl(0);    # XX correct? Argument?
+            repl(skip => 1)
         }
-    }, "FP::Repl::WithRepl::Handler" # just to mark, for Chj::Backtrace ugh
+        }, "FP::Repl::WithRepl::Handler"  # just to mark, for Chj::Backtrace ugh
 }
 
 sub handler ($) {
-    my ($skip)= @_;
-    handler_for (current_user_frame($skip),
-                 $SIG{__DIE__})
+    my ($skip) = @_;
+    handler_for(current_user_frame($skip), $SIG{__DIE__})
 }
 
 sub withrepl (&) {
-    local $SIG{__DIE__}= handler (0);
-    &{$_[0]}()
+    local $SIG{__DIE__} = handler(0);
+    &{ $_[0] }()
 }
 
-
-TEST { withrepl { 1+2 } }
- 3;
-TEST { [ withrepl { "hello", "world" } ] }
-  [ 'hello', 'world' ];
-
+TEST {
+    withrepl { 1 + 2 }
+}
+3;
+TEST {
+    [withrepl { "hello", "world" }]
+}
+['hello', 'world'];
 
 our @stack;
 
 sub push_withrepl ($) {
-    my ($skip)= @_;
+    my ($skip) = @_;
     push @stack, $SIG{__DIE__};
-    $SIG{__DIE__}= handler ($skip);
+    $SIG{__DIE__} = handler($skip);
 }
 
 sub pop_withrepl () {
-    $SIG{__DIE__}= pop @stack;
+    $SIG{__DIE__} = pop @stack;
 }
 
-
 1
 
