@@ -16,13 +16,13 @@ FP::Trampoline -- tail call optimization without reliance on goto
     use FP::Trampoline; # exports `T` and `trampoline`
 
     sub iterative_fact {
-        my ($n,$tot)= @_;
+        my ($n,$tot) = @_;
         $n > 1 ? T{ iterative_fact ($n-1, $tot*$n) } : $tot
         # or
         # $n > 1 ? TC *iterative_fact, $n-1, $tot*$n : $tot
     }
     sub fact {
-        my ($n)=@_;
+        my ($n) = @_;
         trampoline iterative_fact ($n, 1)
     }
     is fact(5), 120;
@@ -73,14 +73,15 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::Trampoline;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(T TC trampoline);
-@EXPORT_OK=qw();
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT      = qw(T TC trampoline);
+our @EXPORT_OK   = qw();
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 sub T (&) {
     bless $_[0], "FP::Trampoline::Continuation"
@@ -91,17 +92,19 @@ sub TC {
 }
 
 sub trampoline ($) {
-    my ($v)=@_;
-    @_=(); # so that calling a continuation does not need () (possible
-           # speedup)
+    my ($v) = @_;
+    @_ = ();    # so that calling a continuation does not need () (possible
+                # speedup)
     while (1) {
-        if (my $r= ref $v) {
-            $v=
-              ($r eq "FP::Trampoline::Continuation" ? &$v
-               : $r eq "FP::Trampoline::Call" ? do {
-                   $$v[0]->(@$v[1..$#$v])
-               }
-               : return $v);
+        if (my $r = ref $v) {
+            $v = (
+                  $r eq "FP::Trampoline::Continuation"
+                ? &$v
+                : $r eq "FP::Trampoline::Call" ? do {
+                    $$v[0]->(@$v[1 .. $#$v])
+                    }
+                : return $v
+            );
         } else {
             return $v
         }
