@@ -16,9 +16,9 @@ FP::fix -- recurse with the fix point combinator
     use FP::fix;
 
     sub fact {
-        my ($z)= @_;
-        my $f= fix sub {
-            my ($f,  $x, $y)=@_;
+        my ($z) = @_;
+        my $f = fix sub {
+            my ($f,  $x, $y) = @_;
             $x > 0 ? $f->($x-1, $x*$y) : $y
         };
         $f->($z, 1)
@@ -41,12 +41,12 @@ The example from the synopsis is equivalent to:
     use Scalar::Util 'weaken';
 
     sub fact2 {
-        my ($z)= @_;
-        my $f; $f= sub {
-            my ($x, $y)=@_;
+        my ($z) = @_;
+        my $f; $f = sub {
+            my ($x, $y) = @_;
             $x > 0 ? $f->($x-1, $x*$y) : $y
         };
-        my $_f= $f; weaken $f;
+        my $_f = $f; weaken $f;
         $f->($z, 1)
     }
     is fact2(5), 120;
@@ -59,31 +59,33 @@ or on the L<website|http://functional-perl.org/>.
 
 =cut
 
-
 package FP::fix;
-@ISA="Exporter"; require Exporter;
-@EXPORT=qw(fix fixn);
-@EXPORT_OK=qw();
-%EXPORT_TAGS=(all=>[@EXPORT,@EXPORT_OK]);
+use strict;
+use warnings;
+use warnings FATAL => 'uninitialized';
+use Exporter "import";
 
-use strict; use warnings; use warnings FATAL => 'uninitialized';
+our @EXPORT      = qw(fix fixn);
+our @EXPORT_OK   = qw();
+our %EXPORT_TAGS = (all => [@EXPORT, @EXPORT_OK]);
 
 # Alternative implementations:
 
 # Y combinator
-*Y= do {
-        my $fix0= sub {
-            my ($fix0, $f)=@_;
-            sub {
-                @_=(&$fix0 ($fix0, $f), @_); goto &$f;
-            }
-        };
-        sub ($) {
-            my ($f)=@_;
-            &$fix0 ($fix0, $f)
+*Y = do {
+    my $fix0 = sub {
+        my ($fix0, $f) = @_;
+        sub {
+            @_ = (&$fix0($fix0, $f), @_);
+            goto &$f;
         }
     };
 
+    sub ($) {
+        my ($f) = @_;
+        &$fix0($fix0, $f)
+    }
+};
 
 # Haskell recursive let based implementation:
 #   XXX move this code to separate file to avoid dependencies
@@ -93,90 +95,95 @@ use strict; use warnings; use warnings FATAL => 'uninitialized';
 use FP::TransparentLazy qw(lazy lazyLight);
 
 # this variant is different since it requires $f to be curried
-*haskell_curried= sub {
-    my ($f)= @_;
-    my $x; $x= &$f(lazy { $x });  # can't use lazyLight here, why?
+*haskell_curried = sub {
+    my ($f) = @_;
+    my $x;
+    $x = &$f(lazy {$x});    # can't use lazyLight here, why?
     $x
 };
 
 use Chj::TEST;
 TEST {
-    my $f= haskell_curried (sub {
-        my ($self)= @_;
+    my $f = haskell_curried(
         sub {
-            my ($x)=@_;
-            $x > 0 ? $x * &$self($x-1) : 1
+            my ($self) = @_;
+            sub {
+                my ($x) = @_;
+                $x > 0 ? $x * &$self($x - 1) : 1
+            }
         }
-    });
-    [ &$f(0), &$f(3) ]
-} [1, 6];
+    );
+    [&$f(0), &$f(3)]
+}
+[1, 6];
 
-
-*haskell_uncurried= sub {
-    my ($f)= @_;
-    my $fc= sub {
-        my ($fc)=@_;
+*haskell_uncurried = sub {
+    my ($f) = @_;
+    my $fc = sub {
+        my ($fc) = @_;
         sub {
-            unshift @_, $fc; goto &$f;
+            unshift @_, $fc;
+            goto &$f;
         };
     };
-    my $x; $x= &$fc(lazy { $x });  # can't use lazyLight here, why?
+    my $x;
+    $x = &$fc(lazy {$x});    # can't use lazyLight here, why?
     $x
 };
 
-
 # indirectly self-referencing through package variable
-*rec=
-    sub ($) {
-        my ($f)=@_;
-        sub {
-            #@_=(fix ($f), @_); goto &$f;
-            unshift @_, fix ($f); goto &$f;
-        }
-    };
+*rec = sub ($) {
+    my ($f) = @_;
+    sub {
+        #@_ = (fix ($f), @_); goto &$f;
+        unshift @_, fix($f);
+        goto &$f;
+    }
+};
 
 # directly locally self-referencing
 
 use Scalar::Util 'weaken';
 
-*weakcycle=
-    sub ($) {
-        my ($f)=@_;
-        my $f2; $f2= sub {
-            unshift @_, $f2; goto &$f
-        };
-        my $f2_=$f2; weaken $f2; $f2_
+*weakcycle = sub ($) {
+    my ($f) = @_;
+    my $f2;
+    $f2 = sub {
+        unshift @_, $f2;
+        goto &$f
     };
-
-
+    my $f2_ = $f2;
+    weaken $f2;
+    $f2_
+};
 
 # choose implementation:
 
 sub fix ($);
 
-*fix= *weakcycle;
-
+*fix = *weakcycle;
 
 # n-ary version:
 
 sub fixn {
-    my (@f)=@_;
+    my (@f) = @_;
     my @ff;
-    for (my $i=0; $i<@f; $i++) {
-        my $f= $f[$i];
-        $ff[$i]= sub {
-            unshift @_, @ff; goto &$f;
+    for (my $i = 0; $i < @f; $i++) {
+        my $f = $f[$i];
+        $ff[$i] = sub {
+            unshift @_, @ff;
+            goto &$f;
         }
     }
-    my @ff_= @ff;
+    my @ff_ = @ff;
+
     # weaken $_ for @ff;
     # ^ XXX: releases too early, same issue as
     #   mentioned in `intro/more_tailcalls`
     wantarray ? @ff_ : do {
-        @ff==1 or die "fixn: got multiple arguments, but scalar context";
+        @ff == 1 or die "fixn: got multiple arguments, but scalar context";
         $ff_[0]
     }
 }
 
-
 1
